pub struct TextIndexEntry {
pub index: Arc<TextIndex>,
pub name: Option<DbString>,
}Expand description
Registered built-in text-index metadata.
Fields
index: Arc<TextIndex>Index data for the (label, property) registration.
name: Option<DbString>Optional explicit catalog name. None means the name is derived at render time.
Implementations
Sourceimpl TextIndexEntry
impl TextIndexEntry
Sourcepub fn new(index: TextIndex, name: Option<DbString>) -> Self
pub fn new(index: TextIndex, name: Option<DbString>) -> Self
Construct a text index entry from the built index and optional name.
Sourcepub fn stats(&self) -> TextIndexStats
pub fn stats(&self) -> TextIndexStats
Return aggregate index counters.
Sourcepub fn memory_usage(&self) -> TextIndexMemoryUsage
pub fn memory_usage(&self) -> TextIndexMemoryUsage
Return an estimated memory usage snapshot for this text index.