TypeViolation

Enum TypeViolation 

#[non_exhaustive]
pub enum TypeViolation { UnknownNodeLabel { id: NodeId, labels: LabelSet, }, UnknownEdgeLabel { id: EdgeId, label: DbString, }, EdgeEndpointTypeMismatch { id: EdgeId, label: DbString, expected_source_type: EdgeEndpointDef, observed_source_type: u32, expected_target_type: EdgeEndpointDef, observed_target_type: u32, }, MissingRequiredProperty { entity_id: EntityId, property: DbString, declared_in: DbString, }, PropertyTypeMismatch { entity_id: EntityId, property: DbString, expected: PropertyValueType, observed: &'static str, }, ExtensionValueRejected { entity_id: EntityId, property: DbString, }, UndeclaredProperty { entity_id: EntityId, property: DbString, }, ImmutablePropertyUpdate { entity_id: EntityId, property: DbString, declared_in: DbString, }, UniquePropertyDuplicate { entity_id: EntityId, conflicting_entity_id: EntityId, property: DbString, declared_in: DbString, }, }
Closed graph type validation failure.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnknownNodeLabel

Node labels do not match any node type.

Fields

id: NodeId

Node ID.

labels: LabelSet

Observed node label set.



UnknownEdgeLabel

Edge label does not match any edge type.

Fields

id: EdgeId

Edge ID.

label: DbString

Observed edge label.



EdgeEndpointTypeMismatch

Edge endpoints do not match the declared edge type endpoints.

Fields

id: EdgeId

Edge ID.

label: DbString

Edge label.

expected_source_type: EdgeEndpointDef

Expected source endpoint.

observed_source_type: u32

Observed source node-type index.

expected_target_type: EdgeEndpointDef

Expected target endpoint.

observed_target_type: u32

Observed target node-type index.



MissingRequiredProperty

Required property is absent or null.

Fields

entity_id: EntityId

Entity that violated the declaration.

property: DbString

Missing property name.

declared_in: DbString

Node or edge type that declares the property.



PropertyTypeMismatch

Property value has the wrong runtime type.

Fields

entity_id: EntityId

Entity that violated the declaration.

property: DbString

Property name.

expected: PropertyValueType

Expected property value type.

observed: &'static str

Observed runtime value type.



ExtensionValueRejected

Value::Extended is not a declarable closed-graph type.

Fields

entity_id: EntityId

Entity that violated the declaration.

property: DbString

Property name.



UndeclaredProperty

Property is not declared by the matched node or edge type.

Fields

entity_id: EntityId

Entity that violated the declaration.

property: DbString

Undeclared property name.



ImmutablePropertyUpdate

Immutable property was updated or removed.

Fields

entity_id: EntityId

Entity that violated the declaration.

property: DbString

Immutable property name.

declared_in: DbString

Node or edge type that declares the property.



UniquePropertyDuplicate

Unique property value is already used by another entity of the declaring type.

Fields

entity_id: EntityId

Entity that violated the declaration.

conflicting_entity_id: EntityId

Existing entity carrying the same value.

property: DbString

Unique property name.

declared_in: DbString

Node or edge type that declares the property.