pub enum VectorIndexValueError {
KindMismatch {
observed: &'static str,
},
DimensionMismatch {
expected: u32,
observed: usize,
},
MetricRejected {
observed: String,
},
}Expand description
Error returned when a value cannot be admitted to a vector index.
Variants
KindMismatch
Value is not a vector.
DimensionMismatch
Vector dimensionality differs from the registration.
MetricRejected
Vector is structurally valid but invalid for the index metric.