pub struct VectorIndex { /* private fields */ }Expand description
Built-in vector index state for one (label, property) registration.
Implementations
Sourceimpl VectorIndex
impl VectorIndex
Sourcepub fn new(kind: VectorIndexKind, dimension: u32) -> GraphResult<Self>
pub fn new(kind: VectorIndexKind, dimension: u32) -> GraphResult<Self>
Construct an empty vector index.
Errors
Returns GraphError::VectorIndexInvalidDimension when dimension is
zero.
Sourcepub fn new_with_hnsw_config(
kind: VectorIndexKind,
dimension: u32,
hnsw_config: Option<HnswIndexConfig>,
) -> GraphResult<Self>
pub fn new_with_hnsw_config( kind: VectorIndexKind, dimension: u32, hnsw_config: Option<HnswIndexConfig>, ) -> GraphResult<Self>
Construct an empty vector index with optional HNSW configuration.
Errors
Returns GraphError::VectorIndexInvalidDimension when dimension is
zero, or GraphError::VectorIndexInvalidHnswConfig when the supplied
HNSW parameters are invalid for the chosen kind.
Sourcepub fn new_with_configs(
kind: VectorIndexKind,
dimension: u32,
hnsw_config: Option<HnswIndexConfig>,
ivf_config: Option<IvfIndexConfig>,
) -> GraphResult<Self>
pub fn new_with_configs( kind: VectorIndexKind, dimension: u32, hnsw_config: Option<HnswIndexConfig>, ivf_config: Option<IvfIndexConfig>, ) -> GraphResult<Self>
Construct an empty vector index with optional ANN construction config.
Errors
Returns GraphError::VectorIndexInvalidDimension when dimension is
zero, GraphError::VectorIndexInvalidHnswConfig when supplied HNSW
parameters are invalid for the chosen kind, or
GraphError::VectorIndexInvalidIvfConfig when supplied IVF parameters
are invalid for the chosen kind.
Sourcepub const fn kind(&self) -> VectorIndexKind
pub const fn kind(&self) -> VectorIndexKind
Return the vector index algorithm kind.
Sourcepub const fn hnsw_config(&self) -> Option<HnswIndexConfig>
pub const fn hnsw_config(&self) -> Option<HnswIndexConfig>
Return the HNSW construction config, if this is an HNSW index.
Sourcepub const fn ivf_config(&self) -> Option<IvfIndexConfig>
pub const fn ivf_config(&self) -> Option<IvfIndexConfig>
Return the IVF construction config, if this is a configured IVF index.
Sourcepub fn cardinality(&self) -> u64
pub fn cardinality(&self) -> u64
Return the number of indexed rows.
Sourcepub const fn rows(&self) -> &RoaringBitmap
pub const fn rows(&self) -> &RoaringBitmap
Borrow the indexed row bitmap.
Sourcepub const fn is_turbo_quant(&self) -> bool
pub const fn is_turbo_quant(&self) -> bool
Return true when this index has a TurboQuant compressed accelerator.
Sourcepub const fn hnsw_metric(&self) -> Option<VectorMetric>
pub const fn hnsw_metric(&self) -> Option<VectorMetric>
Return the HNSW metric, if this is an HNSW index.
Sourcepub const fn ann_metric(&self) -> Option<VectorMetric>
pub const fn ann_metric(&self) -> Option<VectorMetric>
Return the ANN metric, if this is an approximate index.
Sourcepub fn memory_usage(&self) -> VectorIndexMemoryUsage
pub fn memory_usage(&self) -> VectorIndexMemoryUsage
Return an estimated memory usage snapshot for this index.