pub struct VectorIndexRebuildReport {
pub indexes_rebuilt: usize,
pub entries: Vec<VectorIndexRebuildEntry>,
pub reclaimed_hnsw_entries: usize,
pub reclaimed_hnsw_deleted_entries: usize,
pub reclaimed_ivf_entries: usize,
pub reclaimed_ivf_deleted_entries: usize,
pub reclaimed_index_bytes: usize,
pub reclaimed_reachable_bytes: usize,
}Expand description
Result returned after rebuilding all registered vector indexes.
Fields
indexes_rebuilt: usizeNumber of vector-index registrations rebuilt.
entries: Vec<VectorIndexRebuildEntry>Per-index before/after memory accounting.
reclaimed_hnsw_entries: usizeHNSW entries removed by the rebuild, including stale deleted versions.
reclaimed_hnsw_deleted_entries: usizeStale HNSW deleted entries removed by the rebuild.
reclaimed_ivf_entries: usizeIVF entries removed by the rebuild, including stale deleted versions.
reclaimed_ivf_deleted_entries: usizeStale IVF deleted entries removed by the rebuild.
reclaimed_index_bytes: usizeEstimated index-owned bytes reclaimed by the rebuild.
reclaimed_reachable_bytes: usizeEstimated reachable bytes reclaimed, including ANN vector components.