#[non_exhaustive]pub enum TypeViolation {
UnknownNodeLabel {
id: NodeId,
labels: LabelSet,
},
UnknownEdgeLabel {
id: EdgeId,
label: DbString,
},
EdgeEndpointTypeMismatch {
id: EdgeId,
label: DbString,
expected_source_type: EdgeEndpointDef,
observed_source_type: u32,
expected_target_type: EdgeEndpointDef,
observed_target_type: u32,
},
MissingRequiredProperty {
entity_id: EntityId,
property: DbString,
declared_in: DbString,
},
PropertyTypeMismatch {
entity_id: EntityId,
property: DbString,
expected: PropertyValueType,
observed: &'static str,
},
ExtensionValueRejected {
entity_id: EntityId,
property: DbString,
},
UndeclaredProperty {
entity_id: EntityId,
property: DbString,
},
ImmutablePropertyUpdate {
entity_id: EntityId,
property: DbString,
declared_in: DbString,
},
UniquePropertyDuplicate {
entity_id: EntityId,
conflicting_entity_id: EntityId,
property: DbString,
declared_in: DbString,
},
}Expand description
Closed graph type validation failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnknownNodeLabel
Node labels do not match any node type.
UnknownEdgeLabel
Edge label does not match any edge type.
EdgeEndpointTypeMismatch
Edge endpoints do not match the declared edge type endpoints.
Fields

expected_source_type: EdgeEndpointDefExpected source endpoint.

expected_target_type: EdgeEndpointDefExpected target endpoint.
MissingRequiredProperty
Required property is absent or null.
Fields
PropertyTypeMismatch
Property value has the wrong runtime type.
Fields

expected: PropertyValueTypeExpected property value type.
ExtensionValueRejected
Value::Extended is not a declarable closed-graph type.
UndeclaredProperty
Property is not declared by the matched node or edge type.
Fields
ImmutablePropertyUpdate
Immutable property was updated or removed.
Fields
UniquePropertyDuplicate
Unique property value is already used by another entity of the declaring type.